# coding: latin1
""" TestExcel2.py
Test Modulo ExcelXML.py per la generazione di fogli Excel in formato XML

Genera 2 fogli Excel:
nel primo genera 10 stili di celle diversi e scrive 20 righe spostandole diagonalmente
nel secondo presenta un prototipo di fattura semplificata

"""
from ExcelXML import *

# prima preparo la struttura del secondo sheet (per il primo uso il default)
# in cui tolgo la griglia in stampa e imposto intestazioni, bordi e formato Portrait

Sh = xlsSheetStruct()
Sh.PrintGrid = False
Sh.Description = "Descrizione in stampa per il Foglio N.2"
Sh.FootPage = "Pi di pagina in stampa - Pag. &amp;P"
Sh.MarginLeft = 0.8
Sh.MarginRight = 0.2
Sh.Layout = "P"

# istanzia Excel

x1 = xlsExcel("Prova2.xml")

# genero 10 stili per il primo foglio
for i in range(0, 10):
   st = xlsStyleStruct()
   # differezia gli stili a 3 a 3 (a caso)
   if i % 3 == 0:
      st.VAlign = "Center"
      st.FontName = "Courier New"
      st.FontColor = "red"
      st.FontBold  = True
      st.BGcolor = "#d0ffff"
   if i % 3 == 1:
      st.VAlign = "Top"
      st.FontName = "Times"
      st.FontColor = "green"
      st.FontItalic  = True
      st.BGcolor = "#ffd0ff"
   if i % 3 == 2:
      st.FontName = "Arial"
      st.FontColor = "blue"
      st.BGcolor = "#ffffd0"
   st.FontSize = 7 + i*2
   st.ID = "S" + str(i)
   x1.xlsAddStyle(st)

# genero altri stili con bordo per il secondo foglio
st = xlsStyleStruct()
st.ID = "bw"
st.BorderTop = 1
st.BorderBottom = 1
st.BorderLeft = 1
st.BorderRight = 1
st.FontBold  = True
st.FontSize = 10
st.VAlign = "Top"
st.WrapText = True
x1.xlsAddStyle(st)

st.ID = "bw1"
st.FontBold  = False
x1.xlsAddStyle(st)

st.ID = "bw2"
st.FontBold  = True
st.Align = "Right"
x1.xlsAddStyle(st)

st.ID = "bg"
st.Align = "Left"
st.BGcolor = "#e0e0e0"
x1.xlsAddStyle(st)

st.ID = "bgr"
st.Align = "Right"
x1.xlsAddStyle(st)

# inizio a generare i fogli
x1.xlsAddSheet("Foglio 1")  # il primo foglio ha lo sheet di default

# allarga le colonne progressivamente
for i in range(0, 12):
   x1.xlsColumn(i+1,10+(i*8))

x1.xlsWriteCell("Genera 10 stili di celle diversi e scrive 20 righe spostandole diagonalmente ")
x1.xlsNewLine(1)

# scrive le celle
for i in range(0, 10):
   x1.xlsWriteCell(i,"N","S" + str(i),"",i)   # con progressivo spostamento a destra
   x1.xlsWriteCell("Descrizione","S","S" + str(i))
   x1.xlsNewLine(0,20+i*4)   # salto riga con allargamento spessore

for i in range(0, 10):
   x1.xlsWriteCell(10-i,"N","S" + str(i),"",10-i)
   x1.xlsWriteCell("Descrizione","S","S" + str(i))
   x1.xlsNewLine()

# Secondo foglio
x1.xlsAddSheet("Fattura", Sh)

# allarga le colonne
x1.xlsColumn(1,80)
x1.xlsColumn(2,100)
x1.xlsColumn(3,100)
x1.xlsColumn(4,50)
x1.xlsColumn(5,50)
x1.xlsColumn(6,50)

x1.xlsWriteCell("Prototipo di fattura semplificata ", MergeAcross=2) # con MergeAcross ingloba le due celle successive
# Testata fattura
x1.xlsNewLine(1,40)
x1.xlsWriteCell("Cliente:","S","","",2)
x1.xlsWriteCell("ACME, Via Garibaldi 121, 40100 BOLOGNA","S","bg", MergeAcross=2)
x1.xlsNewLine(1,20)
x1.xlsWriteCell("Data: 1/1/2008","S","bw","")
x1.xlsWriteCell("Ordine: 1234","S","bw",MergeAcross=2)
x1.xlsWriteCell("Fattura: 21","S","bw",MergeAcross=1)
x1.xlsNewLine(1)
x1.xlsWriteCell("Codice","S","bg","")
x1.xlsWriteCell("Descrizione","S","bg",MergeAcross=1)
x1.xlsWriteCell("Quantit","S","bg")
x1.xlsWriteCell("Prezzo","S","bg")
x1.xlsWriteCell("Totale","S","bg")
# Dettaglio fattura
nRighe = 8
for i in range(1,1+nRighe):
   x1.xlsNewLine()
   x1.xlsWriteCell(str(1000+i*3),"S","bw1","")
   x1.xlsWriteCell("Prodotto Descrizione "+ str(i),"S","bw1",MergeAcross=1)
   x1.xlsWriteCell(1,"N","bw2")
   x1.xlsWriteCell(7+i*2,"N","bw2")
   x1.xlsWriteCell(7+i*2,"N","bw2")
x1.xlsNewLine()
# Totali
x1.xlsWriteCell("TOTALI:","S","bgr",MergeAcross=2)
# usa le formule di Excel per ottenere i totali nelle celle
x1.xlsWriteCell(" ","S","bgr",Formula="=SUM(R[-" + str(nRighe) +"]C:R[-1]C)")
x1.xlsWriteCell(" ","S","bgr",Formula="=SUM(R[-" + str(nRighe) +"]C:R[-1]C)")
x1.xlsWriteCell(" ","S","bgr",Formula="=SUM(R[-" + str(nRighe) +"]C:R[-1]C)")

x1.xlsClose()
# ------------------------------------------
print "E' stato generato il file 'Prova2.xml'"
